# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages, os, Command  # noqa: H301

NAME = "docusign-rooms"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23",
    "setuptools >= 21.0.0",
    "PyJWT>=1.7.1",
    "cryptography>=2.5",
    "nose>=1.3.7"
]

class CleanCommand(Command):
    """Custom clean command to tidy up the project root."""
    user_options = []
    def initialize_options(self):
        pass
    def finalize_options(self):
        pass
    def run(self):
        os.system('rm -vrf ./build ./dist ./*.pyc ./*.tgz ./*.egg-info')

setup(
    name=NAME,
    version=VERSION,
    description="DocuSign Rooms API - v2",
    author_email="devcenter@docusign.com",
    url="",
    keywords=["Swagger", "DocuSign Rooms API - v2"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    cmdclass={
        'clean': CleanCommand,
    },
    long_description="""\
    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501
    """
)
